@@ -24,12 +24,24 @@ class LppType(object):
                  [True, True, True]),
         115:    ('Barometer', [2], [10], [False]),
         116:    ('Voltage', [2], [100], [False]),
+        117:    ('Current', [2], [1000], [False]),
+        118:    ('Frequency', [4], [1], [False]),
+        120:    ('Percentage', [1], [1], [False]),
+        121:    ('Altitude', [2], [1], [True]),
         122:    ('Load', [3], [1000], [True]),
+        125:    ('Concentration', [2], [1], [False]),
+        128:    ('Power', [2], [1], [False]),
+        130:    ('Distance', [4], [1000], [False]),
+        131:    ('Energy', [4], [1000], [False]),
+        132:    ('Direction', [2], [1], [False]),
         133:    ('Unix Timestamp', [4], [1], [False]),
         134:    ('Gyrometer', [2, 2, 2], [100, 100, 100],
                  [True, True, True]),
+        135:    ('Colour', [1, 1, 1], [1, 1, 1],
+                 [False, False, False]),
         136:    ('GPS Location', [3, 3, 3], [10000, 10000, 100],
-                 [True, True, True])
+                 [True, True, True]),
+        142:    ('Switch', [1], [1], [False])
     }
 
     def __init__(self, type_, name, sizes, scales, signs):
@@ -44,8 +56,6 @@ class LppType(object):
             raise TypeError('Parameter (scales) must be a list of integers!')
         if not isinstance(signs, list):
             raise TypeError('Parameter (signs) must be a list of integers!')
-        if type_ not in self.__lpp_types:
-            raise ValueError('Invalid parameter: unknown type!')
         if len(sizes) != len(scales) or len(scales) != len(signs):
             raise ValueError('Invalid parameter length: sizes, scales, signs!')
         self.type = type_
@@ -64,7 +74,7 @@ class LppType(object):
         if not isinstance(data, tuple):
             data = (data,)
         if not len(data) == num:
-            raise AssertionError()
+            raise ValueError()
         return data
 
     @staticmethod
@@ -148,13 +158,13 @@ class LppType(object):
         for i in range(len(self.sizes)):
             size = self.sizes[i]
             value = data[i]
-            value *= self.scales[i]
-            if not self.signs[i]:
-                if value < 0:
-                    raise ValueError('Invalid data, must be non negative!')
-                maxval = 1 << (size * 8)
-                if value >= maxval:
-                    raise ValueError('Invalid data, exceed value range!')
+            if not self.signs[i] and value < 0:
+                raise ValueError('Invalid data, must be non negative!')
+            value = int(value * self.scales[i])
+            maxval = 1 << (size * 8)
+            if value >= maxval:
+                raise ValueError('Invalid data, exceed value range!')
+            if self.signs[i]:
                 value = self.__to_unsigned(value)
             buf[pos:(pos + size)] = self.__to_bytes(value, size)
             pos += size
